#!/usr/bin/env python
# -*- coding: utf-8 -*- 

execfile("header.py")

def design():
    #---------------------------------------------------------------------------
    # This script should define a Dseqrecord named seq
    
    from pydna import pcr
    from pydna import parse
    from pydna import Genbank
    from pydna import Assembly
    from pydna import Dseqrecord
    
    p577,578,p468,p467,p567,p568  =  parse('''  >577        
                                                gttctgatcctcgagcatcttaagaattc                                                
                                                >578          
                                                gttcttgtctcattgccacattcataagt
                                                >468
                                                gtcgaggaacgccaggttgcccact
                                                >467 
                                                ATTTAAatcctgatgcgtttgtctgcacaga
                                                >567
                                                GTcggctgcaggtcactagtgag
                                                >568
                                                GTGCcatctgtgcagacaaacg''')
                                                
    from Bio.Restriction import ZraI, AjiI, EcoRV
    
    from pYPKpw import pYPKpw
    
    pYPKpw_lin = pYPK0.linearize(EcoRV)
    
    from pYPKa_Z_TEF1tp import pYPKa_Z_TEF1tp as first
    from pYPKa_A_SsXYL1 import pYPKa_A_SsXYL1 as middle
    from pYPKa_E_TDH3tp import pYPKa_E_TDH3tp as last                                                                               

    first  = pcr( p577, p567, first)
    middle = pcr( p468, p467, middle)
    last   = pcr( p568, p578, last)
    
    a = Assembly((pYPKpw_lin, first, middle, last))
    
    print asm.analyze_overlaps(limit=31)

    print asm.create_graph()

    print asm.assemble_circular_from_graph()

    seq = asm.circular_products[0]
    
    seq=seq.synced("tcgcgcgtttcggtgatgacggtgaaaacctctg")

    # This script should define a Dseqrecord named seq
    #---------------------------------------------------------------------------
    assert isinstance(seq, Dseqrecord)
    return seq

execfile("footer.py")



#!/usr/bin/env python
# -*- coding: utf-8 -*- 

execfile("header.py")

def design():
    #---------------------------------------------------------------------------
    # This script should define a Dseqrecord named seq

    from pCAPs import pCAPs
    from pSU0_EcoRV import pSU0_EcoRV
    from pydna import pcr, parse, Genbank, Assembly
    from Bio.Restriction import ZraI, AjiI, EcoRV, BamHI, EcoRI, PvuI
    
    psu = pSU0_EcoRV.cut(BamHI, EcoRI).pop(0)
    
    pcaps = pCAPs.cut(PvuI).pop()
    
    a = Assembly([psu, pcaps])
    
    print a.analyze_overlaps(limit=200)
    
    print a.create_graph()
    
    print a.assemble_hr_circular()

    seq = a.circular_products[0]
    
    seq=seq.synced(pCAPs)
    
    seq.name = "pYKP0"

    
    # This script should define a Dseqrecord named seq
    #---------------------------------------------------------------------------
    assert isinstance(seq, Dseqrecord)
    return seq
    
execfile("footer.py")



#!/usr/bin/env python
# -*- coding: utf-8 -*- 

execfile("header.py")

def design():
    #---------------------------------------------------------------------------
    # This script should define a Dseqrecord named seq
    
    from pydna import read
    from pydna import Dseqrecord
    from pydna import pcr

    from pYPKa import pYPKa

    from Bio.Restriction import EcoRV
    
    enz = EcoRV
    
    ins = read("PGI.txt")
    
    fp = read('''
>pfw1000
ttaaatAATTCAGTTTTCTGACTGA
''', ds=False)
    
    rp = read('''
>prv1000
taattaaTTTTAGGCTGGTATCTTG
''', ds=False)
    
    pYPKa_cut = pYPKa.linearize(enz)
    
    ins = pcr(fp, rp, ins)
    
    seq = (pYPKa_cut + ins).looped().synced("tcgcgcgtttcggtgatgacggtgaaaacctctg")

    # This script should define a Dseqrecord named seq
    #---------------------------------------------------------------------------
    assert isinstance(seq, Dseqrecord)
    return seq
    
execfile("footer.py")



#!/usr/bin/env python
# -*- coding: utf-8 -*- 

execfile("header.py")

def design():
    #---------------------------------------------------------------------------
    # This script should define a Dseqrecord named seq
       
    from pydna import parse
    from pydna import pcr
    from pydna import Assembly
    from pydna import Dseqrecord
    
    
    (p577,
     p578,
     p775,
     p778) = parse('''>577          
                      gttctgatcctcgagcatcttaagaattc                                                                           
                      >578            
                      gttcttgtctcattgccacattcataagt
                      >775 
                      gcggccgctgacTTAAAT
                      >778 
                      ggtaaatccggatTAATTAA''', ds=False)
    
    from Bio.Restriction import EcoRV

    from pYPKpw import pYPKpw
    
    pYPKpw_lin = pYPK0.linearize(EcoRV)
    
    from pYPK0_TEF1tp_SsXYL1_TDH3tp import pYPK0_TEF1tp_SsXYL1_TDH3tp as cas1
    from pYPK0_TDH3tp_SsXYL2_PGItp import pYPK0_TDH3tp_SsXYL2_PGItp as cas2
    cas1  = pcr( p577, p778, cas1)
    cas2 = pcr( p775, p578, cas2)    
    
    asm = Assembly((pYPKpw_lin, cas1,cas2))

    print asm.analyze_overlaps(limit=61)

    print asm.create_graph()

    print asm.assemble_circular_from_graph()

    seq = asm.circular_products[0]
    
    print seq.small_fig()
            
    seq = seq.synced("tcgcgcgtttcggtgatgacggtgaaaacctctg")     
    
    # This script should define a Dseqrecord named seq
    #---------------------------------------------------------------------------
    assert isinstance(seq, Dseqrecord)
    return seq
    
execfile("footer.py")
    





try:
    seq = read(fname)
except ValueError:
    print "Could not read {}".format(fname)
    print " Executing     {}".format(fname)
    globals().update({name:design()})
    globals()[name].write(fname)
    print "Written        {}".format(fname)
    seq = None
else:
    print "Reading        {}".format(fname)
    globals().update({name:seq})

if __name__=="__main__" or "redo" in sys.argv:
    from pydna import eq
    import shutil
    #print " Executing     {}".format(fname) 
    if seq:
        new = design()
        if new.seq.tostring().lower()==seq.seq.tostring().lower():
            print "new and old sequences are identical."
        else:
            print "new ({}bp) and old ({}bp) sequences are NOT identical!".format(len(new),len(seq))
            if eq(new, seq):
                print "new and old sequences are equivalent."
            else:
                print "new ({}bp) and old ({}bp) sequences are NOT equivalent!".format(len(new),len(seq))
            oldname = "{}_old.gb".format(name)
            shutil.move(fname, oldname)
            new.write(fname)
            print "old = {}".format(oldname)
            print "new = {}".format(fname)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Read version numbers, author etc..
__version__ = "Undefined"
for line in open('./ypkpathway/__init__.py'):
    if line.startswith('__'):
        exec(line.strip())  

from setuptools import setup
import os

setup(  name='ypkpathway',
        version         =__version__,
        author          =__author__,
        author_email    =__email__,
        packages=['ypkpathway'],
        
        package_data={'ypkpathway': [os.path.join('data','*')]},
        
        #package_data={'ypkpathway': [os.path.join('ypkpathway','data','*')]},
        
        entry_points = { 'console_scripts': [ 'ypkpathway = ypkpathway.ypkpathway:main' ]},
        
        url='http://pypi.python.org/pypi/py-genome/',
        license='LICENSE.txt',
        description='''Assemble metabolic pathways from the command line''',
        long_description=open('README.txt').read(),
        install_requires =[ "pydna>=0.6.1", "docutils>=0.11", "docopt>=0.6.1" ],
        test_suite="run_tests.load_my_tests",
        zip_safe = False,
        keywords = "bioinformatics",
        classifiers = ['Development Status :: 3 - Alpha',
                       'Environment :: Console',
                       'Intended Audience :: Education',
                       'Intended Audience :: Science/Research',
                       'License :: OSI Approved :: BSD License',
                       'Programming Language :: Python :: 2.7',
                       'Topic :: Education',
                       'Topic :: Scientific/Engineering :: Bio-Informatics',])
